pub enum FormatStyle {
Printf,
StrFormat,
}Available on crate feature
builtins only.Expand description
Controls the style of the format string.
Like jinja2, minijinja supports two styles of string formatting:
- printf-style:
{{ "%s, %s!"|format(greeting, name) }} str.format()style:{{ "{}, {}!".format(greeting, name) }}
The format_filter function implements both the styles, and you can invoke a
particular style of formatting by passing this enum as an argument.
Variants
Printf
Printf-style format string, described here
StrFormat
str.format() style format string, described
here