pub struct SyntaxConfig { /* private fields */ }Available on crate feature
custom_syntax only.Expand description
The delimiter configuration for the environment and the parser.
Custom syntax configurations require the custom_syntax feature.
Otherwise just the default syntax is available.
You can override the syntax configuration for templates by setting different
delimiters. The end markers can be shared, but the start markers need to be
distinct. It would thus not be valid to configure {{ to be the marker for
both variables and blocks.
let mut environment = Environment::new();
environment.set_syntax(
SyntaxConfig::builder()
.block_delimiters("\\BLOCK{", "}")
.variable_delimiters("\\VAR{", "}")
.comment_delimiters("\\#{", "}")
.build()
.unwrap()
);Implementations
Sourceimpl SyntaxConfig
impl SyntaxConfig
Sourcepub fn builder() -> SyntaxConfigBuilder
pub fn builder() -> SyntaxConfigBuilder
Creates a syntax builder.
Sourcepub fn block_delimiters(&self) -> (&str, &str)
pub fn block_delimiters(&self) -> (&str, &str)
Returns the block delimiters.
Sourcepub fn variable_delimiters(&self) -> (&str, &str)
pub fn variable_delimiters(&self) -> (&str, &str)
Returns the variable delimiters.
Sourcepub fn comment_delimiters(&self) -> (&str, &str)
pub fn comment_delimiters(&self) -> (&str, &str)
Returns the comment delimiters.
Sourcepub fn line_statement_prefix(&self) -> Option<&str>
pub fn line_statement_prefix(&self) -> Option<&str>
Returns the line statement prefix.
Sourcepub fn line_comment_prefix(&self) -> Option<&str>
pub fn line_comment_prefix(&self) -> Option<&str>
Returns the line comment prefix.